@@ -4,16 +4,16 @@ function(x,para) {
     #  SMALL IS USED TO TEST WHETHER X IS EFFECTIVELY AT
     #  THE ENDPOINT OF THE DISTRIBUTION
     SMALL <- 1e-15
-    XI <- para$para[1] 
-    A  <- para$para[2] 
-    K  <- para$para[3] 
+    XI <- para$para[1]
+    A  <- para$para[2]
+    K  <- para$para[3]
 
     f <- vector(mode="numeric")
     for(i in seq(1,length(x))) {
       Y <- (x[i]-XI)/A
       if(Y <= 0) { f[i] <- 0; next }
       if(K == 0) {
-        f[i] <- A^-1 * exp(-1(1-K)*Y)
+        f[i] <- A^-1 * exp(-Y)
       }
       else {
         ARG <- 1-K*Y
